@@ -1,4 +1,4 @@
-#' Six animals
+#' Some animals, their types and their masses
 #'
 #' @format A data frame with 6 rows and 4 variables:
 #' \describe{
@@ -9,15 +9,15 @@
 #' }
 "animals"
 
-#' The composition of two espresso-based beverages
+#' The compositions of some espresso-based beverages
 #'
 #' @format A data frame with 6 rows and 3 variables:
 #' \describe{
-#'   \item{coffee}{the name of the beverage} 
+#'   \item{beverage}{the name of the beverage} 
 #'   \item{ingredient}{the ingredient} 
 #'   \item{proportion}{the proportion of a cup to fill with the ingredient} 
 #' }
-"coffees"
+"beverages"
 
 #' Some craft and their altitudes
 #'
@@ -28,15 +28,15 @@
 #' }
 "altitudes"
 
-#' Robert Frost's poem *Nothing Gold Can Stay*
+#' Robert Frost's poem *Nothing Gold Can Stay* (1923)
 #'
 #' @format A data frame with 8 rows and 5 variables:
 #' \describe{
-#'   \item{label}{a line from the poem} 
+#'   \item{line}{a line from the poem} 
 #'   \item{xmin}{the xmin coordinate with which to draw the word} 
 #'   \item{xmax}{the xmax coordinate with which to draw the word} 
 #'   \item{ymin}{the ymin coordinate with which to draw the word} 
 #'   \item{ymax}{the ymax coordinate with which to draw the word} 
-#'   \item{line}{the line number} 
+#'   \item{linenumber}{the line number} 
 #' }
 "gold"
